@@ -12,6 +12,7 @@ has injected_component_name => (is=>'ro', isa=>'Str', required=>1);
 has injection_parameters => (is=>'ro', isa=>'HashRef', required=>1);
 has get_config => (is=>'ro', isa=>'CodeRef', required=>1, default=>sub { +{} });
 has roles => (is=>'ro', isa=>'ArrayRef', required=>1, default=>sub { +[] });
+has transform_args => (is=>'ro', isa=>'CodeRef', predicate=>'has_transform_args');
 has composed_class => (
   is=>'ro',
   init_arg=>undef,
@@ -19,7 +20,7 @@ has composed_class => (
   lazy=>1,
   default=>sub { Moose::Util::with_traits($_[0]->from, @{$_[0]->roles}) });
 
-my $merge_args = sub {
+sub merge_args {
   my ($self, $app_or_c, @args) = @_;
   my %global_config_args = %{ $self->get_config->($app_or_c) };
 
@@ -32,15 +33,25 @@ my $merge_args = sub {
   # So here you can override global args from the call to model, and for
   # now we just do the dumbest possible merge type.
   return (%global_config_args, @args);
-};
+}
+
+sub transform_args_if_needed {
+  my ($self, $composed_class, $app_or_c, @merged_args) = @_;
+  if($self->has_transform_args) {
+    @merged_args = $self->transform_args->($self, $composed_class, $app_or_c, @merged_args);
+  }
+  return @merged_args;
+}
 
 sub build_new_instance {
   my ($self, $app_or_c, @args) = @_;
-  my @merged_args = $self->$merge_args($app_or_c, @args);
+  my @merged_args = $self->merge_args($app_or_c, @args);
   my $method = $self->method;
   my $composed_class = ref($self->from)||'' eq "CODE" ?
     $self->from : $self->composed_class;
 
+  @merged_args = $self->transform_args_if_needed($composed_class, $app_or_c, @merged_args);
+
   if((ref($method)||'') eq 'CODE') {
     return $self->$method($composed_class, $app_or_c, @merged_args)
   } else {
@@ -87,6 +98,26 @@ instance  OR a coderef that is used to return an instance.  Defaults to 'new'.
 
 A list of L<Moose::Role>s to be composed into your class
 
+=head2 transform_args
+
+A coderef that you can use to transform configuration arguments into something
+more suitable for your class.  For example, the configuration args is typically
+a hash, but your object class may require some positional arguments.
+
+    MyApp->inject_components(
+      'Model::Foo' => {
+        from_class = 'Foo',
+        transform_args => sub {
+          my ($adaptor_instance, $coderef, $app, %args) = @_;
+          my $path = delete $args{path},
+          return ($path, %args);
+        },
+      },
+    );
+
+Should return the args as they as used by the initialization method of the
+'from_class'.
+
 =head2 get_config
 
 =head2 injection_parameters
@@ -95,6 +126,23 @@ A list of L<Moose::Role>s to be composed into your class
 
 TBD
 
+=head1 METHODS
+
+This role exposes the following public methods
+
+=head2 merge_args
+
+Responsible for merging global configuration and anything passed in at call
+time
+
+=head2 transform_args_if_needed
+
+Perform any programmatic argument transformation
+
+=head2 build_new_instance
+
+Responsible for returning a new instance of the component.
+
 =head1 AUTHOR
 
 John Napiorkowski L<email:jjnapiork@cpan.org>
